aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--irati_support.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/irati_support.py b/irati_support.py
index 0432e29..c2815f0 100644
--- a/irati_support.py
+++ b/irati_support.py
@@ -1,5 +1,5 @@
#
# Commands to setup and instruct rlite
#
# Vincenzo Maffione <v.maffione@nextworks.it>
#
@@ -47,9 +47,9 @@ class IRATIExperiment(rhumba.Experiment):
ssh.execute_commands(self.testbed, node.full_name, cmds, time_out = None)
def run(self):
- print("[RLITE experiment] start")
+ print("[IRATI experiment] start")
self.realize()
print("Setting up IRATI on the nodes...")
self.setup()
- print("[RLITE experiment] end")
+ print("[IRATI experiment] end")
@@ -1,5 +1,5 @@
#
-# Commands to setup and instruct rlite
+# Commands to setup and instruct IRATI
#
# Vincenzo Maffione <v.maffione@nextworks.it>